"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTransferrableToken = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const wormhole_1 = require("../../wormhole");
// For a given token, return the corresponding
// Wormhole wrapped token that originated on Ethereum
const getTransferrableToken = (network, chain, address) => {
    if (chain === "Ethereum")
        return wormhole_1.Wormhole.chainAddress("Ethereum", address);
    // get the nativeTokenDetails
    const nToken = sdk_base_1.tokens.getTokenByAddress(network, chain, address);
    if (!nToken)
        throw new Error("Unsupported source token: " + address);
    // find the same token by symbol with an origin of Ethereum
    // this is the token we standardize for transfer
    const xToken = sdk_base_1.tokens.getTokensBySymbol(network, chain, nToken.symbol)?.find((orig) => {
        return orig.original === "Ethereum";
    });
    if (!xToken)
        throw new Error(`Unsupported symbol for chain ${nToken.symbol}: ${chain} `);
    return wormhole_1.Wormhole.chainAddress(xToken.chain, xToken.address);
};
exports.getTransferrableToken = getTransferrableToken;
//# sourceMappingURL=utils.js.map